==> dokuwiki-2012.10.13.tgz: dokuwiki/lib/plugins/usermanager/lang/zh-tw/lang.php <==
<?php
/**
 * English language file
 *
 * @author chinsan <chinsan.tw@gmail.com>
 * @author Li-Jiun Huang <ljhuang.tw@gmail.com>
 * @author http://www.chinese-tools.com/tools/converter-simptrad.html
 * @author Wayne San <waynesan@zerozone.tw>
 * @author Li-Jiun Huang <ljhuang.tw@gmai.com>
 * @author Cheng-Wei Chien <e.cwchien@gmail.com>
 * @author Danny Lin <danny0838@pchome.com.tw>
 * @author Shuo-Ting Jian <shoting@gmail.com>
 * @author syaoranhinata@gmail.com
 */
$lang['menu']                  = '帳號管理器';
$lang['noauth']                = '(帳號認證尚未開放)';
$lang['nosupport']             = '(尚不支援帳號管理)';
$lang['badauth']               = '錯誤的認證機制';
$lang['user_id']               = '帳號';
$lang['user_pass']             = '密碼';
$lang['user_name']             = '真實姓名';
$lang['user_mail']             = 'E-mail';
$lang['user_groups']           = '群組';
$lang['field']                 = '欄位';
$lang['value']                 = '設定值';
$lang['add']                   = '增加';
$lang['delete']                = '刪除';
$lang['delete_selected']       = '刪除所選的';
$lang['edit']                  = '修改';
$lang['edit_prompt']           = '修改該帳號';
$lang['modify']                = '儲存變更';
$lang['search']                = '搜尋';
$lang['search_prompt']         = '開始搜尋';
$lang['clear']                 = '重設篩選條件';
$lang['filter']                = '篩選條件(Filter)';
$lang['summary']               = '顯示帳號 %1$d-%2$d，共 %3$d 筆符合。共有 %4$d 個帳號。';
$lang['nonefound']             = '找不到帳號。共有 %d 個帳號。';
$lang['delete_ok']             = '已刪除 %d 個帳號';
$lang['delete_fail']           = '%d 個帳號刪除失敗。';
$lang['update_ok']             = '已更新該帳號';
$lang['update_fail']           = '更新該帳號時失敗';
$lang['update_exists']         = '變更帳號名稱 (%s) 失敗，因為有同名帳號存在（其他修改已套用）。';
$lang['start']                 = '開始';
$lang['prev']                  = '上一頁';
$lang['next']                  = '下一頁';
$lang['last']                  = '最後一頁';
$lang['edit_usermissing']      = '找不到選取的帳號，可能已被刪除或改為其他名稱。';
$lang['user_notify']           = '通知使用者';
$lang['note_notify']           = '通知信只會在指定使用者新密碼時寄送。';
$lang['note_group']            = '如果沒有指定群組，新使用者將會被加入到預設群組(%s)當中。';
$lang['note_pass']             = '如果沒有輸入這個欄位而且有勾選通知使用者，則會自動產生一組密碼。';
$lang['add_ok']                = '新增使用者成功';
$lang['add_fail']              = '新增使用者失敗';
$lang['notify_ok']             = '通知信已寄出';
$lang['notify_fail']           = '通知信無法寄出';

==> dokuwiki-2013.05.10.tgz: dokuwiki/lib/plugins/usermanager/lang/zh-tw/lang.php <==
<?php
/**
 * English language file
 *
 * @author chinsan <chinsan.tw@gmail.com>
 * @author Li-Jiun Huang <ljhuang.tw@gmail.com>
 * @author http://www.chinese-tools.com/tools/converter-simptrad.html
 * @author Wayne San <waynesan@zerozone.tw>
 * @author Li-Jiun Huang <ljhuang.tw@gmai.com>
 * @author Cheng-Wei Chien <e.cwchien@gmail.com>
 * @author Danny Lin <danny0838@pchome.com.tw>
 * @author Shuo-Ting Jian <shoting@gmail.com>
 * @author syaoranhinata@gmail.com
 * @author Ichirou Uchiki <syaoranhinata@gmail.com>
 */
$lang['menu']                  = '帳號管理器';
$lang['noauth']                = '(帳號認證尚未開放)';
$lang['nosupport']             = '(尚不支援帳號管理)';
$lang['badauth']               = '錯誤的認證機制';
$lang['user_id']               = '帳號';
$lang['user_pass']             = '密碼';
$lang['user_name']             = '名稱';
$lang['user_mail']             = '電郵';
$lang['user_groups']           = '群組';
$lang['field']                 = '欄位';
$lang['value']                 = '設定值';
$lang['add']                   = '增加';
$lang['delete']                = '刪除';
$lang['delete_selected']       = '刪除所選的';
$lang['edit']                  = '修改';
$lang['edit_prompt']           = '修改該帳號';
$lang['modify']                = '儲存變更';
$lang['search']                = '搜尋';
$lang['search_prompt']         = '開始搜尋';
$lang['clear']                 = '重設篩選條件';
$lang['filter']                = '篩選條件 (Filter)';
$lang['summary']               = '顯示帳號 %1$d-%2$d，共 %3$d 筆符合。共有 %4$d 個帳號。';
$lang['nonefound']             = '找不到帳號。共有 %d 個帳號。';
$lang['delete_ok']             = '已刪除 %d 個帳號';
$lang['delete_fail']           = '%d 個帳號無法刪除。';
$lang['update_ok']             = '已更新該帳號';
$lang['update_fail']           = '無法更新該帳號';
$lang['update_exists']         = '無法變更帳號名稱 (%s) ，因為有同名帳號存在。其他修改則已套用。';
$lang['start']                 = '開始';
$lang['prev']                  = '上一頁';
$lang['next']                  = '下一頁';
$lang['last']                  = '最後一頁';
$lang['edit_usermissing']      = '找不到選取的帳號，可能已被刪除或改為其他名稱。';
$lang['user_notify']           = '通知使用者';
$lang['note_notify']           = '通知信只會在指定使用者新密碼時寄送。';
$lang['note_group']            = '如果沒有指定群組，新使用者將會列入至預設群組(%s)當中。';
$lang['note_pass']             = '如果勾選了通知使用者，而沒有輸入這個欄位，則會自動產生一組密碼。';
$lang['add_ok']                = '已新增使用者';
$lang['add_fail']              = '無法新增使用者';
$lang['notify_ok']             = '通知信已寄出';
$lang['notify_fail']           = '通知信無法寄出';
